#ifndef FC_CONFIG_H
#define FC_CONFIG_H
@TOP@

#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_LIBSM
#undef PACKAGE
#undef VERSION
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef LOCALEDIR
#undef HAVE_LIBREADLINE
#undef WITH_GGZ
#undef HAVE_INET_NTOP
#undef GETTEXT_PACKAGE
#undef HAVE_PTHREADS

@BOTTOM@
#endif /* FC_CONFIG_H */
